unit KNGPropE;

interface

uses
  DsgnIntf, TypInfo, Classes;

type
  { The About Box Property Editor }
  TKNGAboutStringProperty = class(TStringProperty)
    procedure Edit; override;
    function GetAttributes: TPropertyAttributes; override;
    function GetValue: string; override;
  end;

  TDBStringProperty = class(TStringProperty)
  public
    function GetAttributes: TPropertyAttributes; override;
    procedure GetValueList(List: TStrings); virtual;
    procedure GetValues(Proc: TGetStrProc); override;
  end;
  TFieldProperty = class(TDBStringProperty)
  public
    procedure GetValueList(List: TStrings); override;
    function GetDataSourcePropName: string; virtual;
  end;

  TKNGBevelProperty = class(TClassProperty)
  public
    procedure Edit; override;
    function GetAttributes: TPropertyAttributes; override;
  end;

implementation

uses KNGConst, Controls, KNGControls, fmKNGAbout, fmKNGBevelDlg, DB;

{ ***** TKNGAboutStringProperty : The About Box Property ***** }

function TKNGAboutStringProperty.GetAttributes: TPropertyAttributes;
begin
  { The Property Editor should show a Dialog Box and the Property itself
    is Read Only }
  Result := [paDialog, paReadOnly]
end;

function TKNGAboutStringProperty.GetValue: string;
begin
  Result := rsPropAbout;
end;

procedure TKNGAboutStringProperty.Edit;
begin
  with TfrmKNGAbout.Create(nil) do
  begin
    try
      ShowModal;
    finally
      Free;
    end;
  end;
end;

{ Property Editors which simply come from the RxLib }

function TFieldProperty.GetDataSourcePropName: string;
begin
  Result := 'LookupSource';
end;

procedure TFieldProperty.GetValueList(List: TStrings);
var
  Instance: TComponent;
  PropInfo: PPropInfo;
  DataSource: TDataSource;
begin
  Instance := TComponent(GetComponent(0));
  PropInfo := TypInfo.GetPropInfo(Instance.ClassInfo, GetDataSourcePropName);
  if (PropInfo <> nil) and (PropInfo^.PropType^.Kind = tkClass) then
  begin
    DataSource := TObject(GetOrdProp(Instance, PropInfo)) as TDataSource;
    if (DataSource <> nil) and (DataSource.DataSet <> nil) then
      DataSource.DataSet.GetFieldNames(List);
  end;
end;

function TDBStringProperty.GetAttributes: TPropertyAttributes;
begin
  Result := [paValueList, paSortList, paMultiSelect];
end;

procedure TDBStringProperty.GetValues(Proc: TGetStrProc);
var
  I: Integer;
  Values: TStringList;
begin
  Values := TStringList.Create;
  try
    GetValueList(Values);
    for I := 0 to Values.Count - 1 do Proc(Values[I]);
  finally
    Values.Free;
  end;
end;

procedure TDBStringProperty.GetValueList(List: TStrings);
begin
end;

procedure TKNGBevelProperty.Edit;
var
  tmpBevel : TKNGBevel;
begin
  tmpBevel := TKNGBevel.Create;
  with TKNGBevelDlg.Create(Nil) do
  begin
    try
      tmpBevel.Assign(TKNGBevel(Pointer(GetOrdValue)));
      if ShowModal = mrOk then
      begin
        tmpBevel.Assign(pnlTest.Bevel);
        SetOrdValue(Longint(Pointer(tmpBevel)));
      end;
    finally
    begin
      Free;
      tmpBevel.Free;
    end;
    end;
  end;
end;

function TKNGBevelProperty.GetAttributes: TPropertyAttributes;
begin
  Result := [paDialog, paSubProperties, paMultiSelect];
end;

end.
